#
# Conditional build:
%bcond_without	python	# Python binding
%bcond_with	dnstap	# dnstap replication support
#
Summary:	Recursive, validating DNS resolver
Summary(pl.UTF-8):	Rekurencyjny, weryfikujący resolver DNS
Name:		unbound
Version:	1.5.10
Release:	1
License:	BSD
Group:		Applications/Network
Source0:	http://www.unbound.net/downloads/%{name}-%{version}.tar.gz
# Source0-md5:	0a3a236811f1ab5c1dc31974fa74e047
Source1:	%{name}.init
Source2:	%{name}.service
Source3:	https://data.iana.org/root-anchors/icannbundle.pem
# Source3-md5:	1ad315c80d044eca2da29785eee6f7c3
Source4:	ftp://ftp.internic.net/domain/named.cache
# Source4-md5:	bd84dce11de35801683aaedc339c43ed
Patch0:		%{name}-default_trust_anchor.patch
Patch1:		%{name}-sh.patch
Patch2:		%{name}-pythondir.patch
URL:		http://unbound.net/
BuildRequires:	autoconf >= 2.56
BuildRequires:	automake
BuildRequires:	expat-devel
%{?with_dnstap:BuildRequires:	fstrm-devel}
BuildRequires:	libevent-devel
BuildRequires:	libtool
BuildRequires:	openssl-devel >= 1.0
%{?with_dnstap:BuildRequires:	protobuf-c-devel}
BuildRequires:	rpmbuild(macros) >= 1.228
%if %{with python}
BuildRequires:	python-devel >= 1:2.4.0
BuildRequires:	swig-python
%endif
Requires(post,preun):	/sbin/chkconfig
BuildRequires:	rpmbuild(macros) >= 1.671
Provides:	user(unbound)
Requires(postun):	/usr/sbin/userdel
Requires(pre):	/bin/id
Requires(pre):	/usr/sbin/useradd
Requires:	systemd-units >= 38
Requires:	%{name}-libs = %{version}-%{release}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Unbound is a validating, recursive, and caching DNS resolver.

The C implementation of Unbound is developed and maintained by NLnet
Labs. It is based on ideas and algorithms taken from a Java prototype
developed by Verisign labs, Nominet, Kirei and ep.net.

Unbound is designed as a set of modular components, so that also
DNSSEC (secure DNS) validation and stub-resolvers (that do not run as
a server, but are linked into an application) are easily possible.

%description -l pl.UTF-8
Unbound to weryfikujący, rekurencyjny i cache'ujący resolver (kod
rozwiązujący nazwy) DNS.

Implementacja Unbound w C jest tworzona i utrzymywana przez NLnet
Labs. Jest oparta na pomysłach i algorytmach zaczerpniętych z
prototypu w Javie stworzonego przez Verisign Labs, Nominet, Kirei oraz
ep.net.

Unbound został zaprojektowany jako zbiór modularnych komponentów, więc
możliwe są także weryfikacja DNSSEC (bezpieczny DNS) oraz
resolvery-zaślepki (nie działające jako serwer, ale wbudowane w
aplikację).

%package libs
Summary:	Unbound shared library
Summary(pl.UTF-8):	Biblioteka współdzielona Unbound
Group:		Libraries
Conflicts:	unbound < 1.4.18-1

%description libs
Unbound shared library.

%description libs -l pl.UTF-8
Biblioteka współdzielona Unbound.

%package devel
Summary:	Header files for unbound library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki unbound
Group:		Development/Libraries
Requires:	%{name}-libs = %{version}-%{release}
Requires:	openssl-devel

%description devel
Header files for unbound library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki unbound.

%package static
Summary:	Static unbound library
Summary(pl.UTF-8):	Statyczna biblioteka unbound
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static unbound library.

%description static -l pl.UTF-8
Statyczna biblioteka unbound.

%package -n python-unbound
Summary:	Python interface to unbound library
Summary(pl.UTF-8):	Pythonowy interfejs do biblioteki unbound
Group:		Python/Libraries
Requires:	%{name}-libs = %{version}-%{release}

%description -n python-unbound
Python interface to unbound library.

%description -n python-unbound -l pl.UTF-8
Pythonowy interfejs do biblioteki unbound.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
%{__libtoolize}
%{__aclocal}
%{__autoconf}
%{__autoheader}
%configure \
	%{?with_dnstap:--enable-dnstap} \
	%{__with_without python pyunbound} \
	%{__with_without python pythonmodule} \
	--with-pidfile=/run/%{name}.pid \
	--with-chroot-dir="" \
	--with-conf-file=%{_sysconfdir}/%{name}/%{name}.conf \
	--with-rootkey-file=/var/lib/%{name}/root.key \
	--with-rootcert-file=%{_sysconfdir}/%{name}/icannbundle.pem

%{__make}

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{/etc/rc.d/init.d,%{systemdunitdir},/var/lib/%{name}}

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

install %{SOURCE1} $RPM_BUILD_ROOT/etc/rc.d/init.d/%{name}
install %{SOURCE2} $RPM_BUILD_ROOT%{systemdunitdir}/%{name}.service
install %{SOURCE3} $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/icannbundle.pem
install %{SOURCE4} $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/named.cache

touch $RPM_BUILD_ROOT/var/lib/%{name}/root.key

%if %{with python}
%{__rm} $RPM_BUILD_ROOT%{py_sitedir}/_unbound.la
%py_comp $RPM_BUILD_ROOT%{py_sitedir}
%py_ocomp $RPM_BUILD_ROOT%{py_sitedir}
%py_postclean
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/chkconfig --add %{name}
%systemd_post %{name}.service
%service %{name} restart

%pre
%useradd -u 196 -g 99 -d /tmp -s /bin/false -c "unbound user" unbound

%preun
if [ "$1" = "0" ]; then
	%service -q %{name} stop
	/sbin/chkconfig --del %{name}
fi
%systemd_preun %{name}.service

%postun
if [ "$1" = "0" ]; then
	%userremove unbound
fi
%systemd_reload

%triggerpostun -- %{name} < 1.4.22-1
%systemd_trigger %{name}.service

%post	libs -p /sbin/ldconfig
%postun	libs -p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc doc/{CREDITS,Changelog,FEATURES,LICENSE,README,TODO,control_proto_spec.txt,example.conf,ietf67-design-02.pdf,requirements.txt}
%attr(754,root,root) /etc/rc.d/init.d/unbound
%{systemdunitdir}/%{name}.service
%dir %{_sysconfdir}/%{name}
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/%{name}/unbound.conf
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/%{name}/named.cache
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/%{name}/icannbundle.pem
%attr(755,root,root) %{_sbindir}/unbound
%attr(755,root,root) %{_sbindir}/unbound-anchor
%attr(755,root,root) %{_sbindir}/unbound-checkconf
%attr(755,root,root) %{_sbindir}/unbound-control*
%attr(755,root,root) %{_sbindir}/unbound-host
%{_mandir}/man1/unbound-host.1*
%{_mandir}/man5/unbound.conf.5*
%{_mandir}/man8/unbound-checkconf.8*
%{_mandir}/man8/unbound.8*
%{_mandir}/man8/unbound-anchor.8*
%{_mandir}/man8/unbound-control*.8*
%dir %attr(755,unbound,nobody) /var/lib/%{name}
%ghost /var/lib/%{name}/root.key

%files libs
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libunbound.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libunbound.so.2

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libunbound.so
%{_libdir}/libunbound.la
%{_includedir}/unbound.h
%{_mandir}/man3/libunbound.3*
%{_mandir}/man3/ub_*.3*

%files static
%defattr(644,root,root,755)
%{_libdir}/libunbound.a

%if %{with python}
%files -n python-unbound
%defattr(644,root,root,755)
%attr(755,root,root) %{py_sitedir}/_unbound.so*
%{py_sitedir}/unbound.py[co]
%{py_sitedir}/unboundmodule.py[co]
%endif
%changelog
* Sun Oct 02 2016 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/unbound.git;a=log;h=master

* Sun Oct 02 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> e6a0f95
- up to 1.5.10

* Sun Jun 19 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> 2e0bfa5
- up to 1.5.9

* Sun Mar 06 2016 Jakub Bogusz <qboosh@pld-linux.org> dffb614
- updated to 1.5.8

* Wed Mar 02 2016 Jakub Bogusz <qboosh@pld-linux.org> 05a660e
- updated to 1.5.7
- added pythondir patch to fix build after python configuration changes

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> 42c1368
- release 2 (by relup.sh)

* Mon Nov 02 2015 Jakub Bogusz <qboosh@pld-linux.org> 60c650c
- added dnstap bcond

* Mon Nov 02 2015 Jakub Bogusz <qboosh@pld-linux.org> f33b27d
- updated to 1.5.6
- added sh patch (fix quotes inside backticks issue)

* Fri Sep 25 2015 Arkadiusz Miśkiewicz <arekm@maven.pl> d1474b1
- up to 1.5.4

* Tue Aug 04 2015 Jacek Konieczny <j.konieczny@eggsoft.pl> e5f6e16
- Make python bcond more reliable

* Thu Jul 02 2015 Jakub Bogusz <qboosh@pld-linux.org> 9b98638
- updated to 1.5.3

* Thu Feb 26 2015 Jakub Bogusz <qboosh@pld-linux.org> 6cbb45b
- updated to 1.5.2
- removed obsolete IP_PMTUDISC_OMIT patch

* Tue Feb 24 2015 Jan Rękorajski <baggins@pld-linux.org> 5a8c9dc
- x32 rebuild
- release 3 (by relup.sh)

* Thu Dec 18 2014 Jacek Konieczny <j.konieczny@eggsoft.pl> 43c09d6
- missing patch added

* Thu Dec 18 2014 Jacek Konieczny <j.konieczny@eggsoft.pl> 7371929
- Fix crash on compile/runtime kernel version mismatch

* Wed Dec 10 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> 42c6638
- up to 1.5.1; fixes CVE-2014-8602

* Fri Apr 25 2014 Jacek Konieczny <jajcus@jajcus.net> 175d642
- Release: 2

* Fri Apr 25 2014 Jacek Konieczny <j.konieczny@eggsoft.pl> b53232e
- Set the auto-trust-anchor-file by default

* Fri Apr 25 2014 Jacek Konieczny <j.konieczny@eggsoft.pl> 267353b
- disable chroot in the default config

* Fri Apr 25 2014 Jacek Konieczny <j.konieczny@eggsoft.pl> f959c39
- Run unbound-checkconf after unbound-anchor

* Tue Apr 01 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> c0601a6
- make unbound-anchor quiet

